@@ -4,13 +4,14 @@
 // Invenio RDM Records is free software; you can redistribute it and/or modify it
 // under the terms of the MIT License; see LICENSE file for more details.
 
-import RequestComponent from './Request';
-import { connect } from 'react-redux';
-import { initRequest, updateRequestAfterAction } from './state/actions';
+import { connect } from "react-redux";
+import RequestComponent from "./Request";
+import { initRequest, updateRequestAfterAction } from "./state/actions";
 
 const mapDispatchToProps = (dispatch) => ({
   initRequest: () => dispatch(initRequest()),
-  updateRequestAfterAction: (request) => dispatch(updateRequestAfterAction(request))
+  updateRequestAfterAction: (request) =>
+    dispatch(updateRequestAfterAction(request)),
 });
 
 const mapStateToProps = (state) => ({
@@ -22,3 +23,4 @@ export const Request = connect(
   mapDispatchToProps
 )(RequestComponent);
 
+export * from "./IconStatus";
