@@ -12,7 +12,16 @@ import {
   TimelineCancelEvent,
   TimelineDeclineEvent,
   TimelineExpireEvent,
+  TimelineUnknownEvent,
 } from "./timelineEvents";
+import {
+  IconSubmitStatus,
+  IconDeleteStatus,
+  IconAcceptStatus,
+  IconDeclineStatus,
+  IconCancelStatus,
+  IconExpireStatus,
+} from "./request";
 
 const requestDetailsDiv = document.getElementById("request-detail");
 const request = JSON.parse(requestDetailsDiv.dataset.record);
@@ -21,10 +30,17 @@ const defaultQueryParams = JSON.parse(
 );
 
 const overriddenComponents = {
-  "TimelineEvent.layout.D": TimelineDeclineEvent,
-  "TimelineEvent.layout.A": TimelineAcceptEvent,
-  "TimelineEvent.layout.E": TimelineExpireEvent,
-  "TimelineEvent.layout.X": TimelineCancelEvent,
+  "TimelineEvent.layout.unknown": TimelineUnknownEvent,
+  "TimelineEvent.layout.declined": TimelineDeclineEvent,
+  "TimelineEvent.layout.accepted": TimelineAcceptEvent,
+  "TimelineEvent.layout.expired": TimelineExpireEvent,
+  "TimelineEvent.layout.cancelled": TimelineCancelEvent,
+  "RequestStatusIcon.layout.submitted": IconSubmitStatus,
+  "RequestStatusIcon.layout.deleted": IconDeleteStatus,
+  "RequestStatusIcon.layout.accepted": IconAcceptStatus,
+  "RequestStatusIcon.layout.declined": IconDeclineStatus,
+  "RequestStatusIcon.layout.cancelled": IconCancelStatus,
+  "RequestStatusIcon.layout.expired": IconExpireStatus,
 };
 
 ReactDOM.render(
