@@ -74,11 +74,11 @@ class RequestsServiceConfig(RecordServiceConfig, ConfiguratorMixin):
     # links configuration
     links_item = {
         "self": RequestLink("{+api}/requests/{id}"),
-        "self_html": RequestLink("{+ui}/requests/{id}"),
         "comments": RequestLink("{+api}/requests/{id}/comments"),
         "timeline": RequestLink("{+api}/requests/{id}/timeline"),
     }
     links_search = pagination_links("{+api}/requests{?args*}")
+    links_user_requests_search = pagination_links("{+api}/user/requests{?args*}")
     action_link = RequestLink(
         "{+api}/requests/{id}/actions/{action}", when=_is_action_available
     )
