@@ -12,11 +12,22 @@
 from datetime import timezone
 
 from invenio_records_resources.services.records.schema import BaseRecordSchema
-from marshmallow import RAISE, Schema, fields, missing, validate
-from marshmallow_oneofschema import OneOfSchema
+from marshmallow import (
+    INCLUDE,
+    RAISE,
+    Schema,
+    ValidationError,
+    fields,
+    post_dump,
+    post_load,
+    validate,
+)
 from marshmallow_utils import fields as utils_fields
 
-from ..records.api import RequestEventFormat, RequestEventType
+from invenio_requests.proxies import current_requests
+
+from ..customizations.event_types import CommentEventType, EventType
+from ..proxies import current_event_type_registry
 
 
 class RequestSchema(BaseRecordSchema):
@@ -65,58 +76,34 @@ class GenericRequestSchema(RequestSchema):
     topic = fields.Dict()
 
 
-class ModelFieldStr(fields.Str):
-    """Marshmallow field for serializing by attribute before item."""
+class EventTypeMarshmallowField(fields.Str):
+    """Serializes event type from `EventType` to string."""
 
-    def get_value(self, obj, attr, **kwargs):
-        """Return obj.attr or obj[attr] in this precedence order."""
-        return getattr(obj, attr, obj.get(attr, missing))
+    def _serialize(self, value, attr, data, **kwargs):
+        if isinstance(value, EventType):
+            value = value.type_id
+        return value
 
 
-class BaseEventSchema(BaseRecordSchema):
+class RequestEventSchema(BaseRecordSchema):
     """Base Event schema that other schemas should inherit from."""
 
-    type = ModelFieldStr(required=True)
+    type = EventTypeMarshmallowField(dump_only=True)
     created_by = fields.Dict(dump_only=True)
+    permissions = fields.Method("get_permissions", dump_only=True)
 
-
-class CommentSchema(BaseEventSchema):
-    """Comment schema."""
-
-    class CommentExtra(Schema):
-        """Comment extras schema."""
-
-        content = utils_fields.SanitizedHTML(
-            required=True, validate=validate.Length(min=1)
-        )
-        format = fields.Str(
-            validate=validate.OneOf(choices=[e.value for e in
-                                             RequestEventFormat]),
-            load_default=RequestEventFormat.HTML.value,
-        )
-
-    payload = fields.Nested(CommentExtra, required=True)
-
-
-class NoExtrasSchema(BaseEventSchema):
-    """No extras schema."""
-
-
-class RequestEventSchema(BaseRecordSchema, OneOfSchema):
-    """Schema."""
-
-    # TODO: Make this schema hookable? how?
-
-    type_schemas = {
-        RequestEventType.COMMENT.value: CommentSchema,
-        RequestEventType.ACCEPTED.value: NoExtrasSchema,
-        RequestEventType.DECLINED.value: NoExtrasSchema,
-        RequestEventType.CANCELLED.value: NoExtrasSchema,
-        RequestEventType.REMOVED.value: NoExtrasSchema,
-        RequestEventType.EXPIRED.value: NoExtrasSchema,
-    }
-    type_field_remove = False
-
-    def get_obj_type(self, obj):
-        """Return key of type_schemas to use given object to dump."""
-        return obj.type
+    def get_permissions(self, obj):
+        """Return permissions to act on comments or empty dict."""
+        is_comment = obj.type == CommentEventType
+        if is_comment:
+            service = current_requests.request_events_service
+            return {
+                "can_update_comment": service.check_permission(
+                    self.context['identity'], "update_comment", event=obj
+                ),
+                "can_delete_comment": service.check_permission(
+                    self.context['identity'], "delete_comment", event=obj
+                ),
+            }
+        else:
+            return {}
